==> huaweicloudsdkdli-3.0.108-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/show_node_connectivity_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowNodeConnectivityRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'task_id': 'str',
        'queue_name': 'str'
    }

    attribute_map = {
        'task_id': 'task_id',
        'queue_name': 'queue_name'
    }

    def __init__(self, task_id=None, queue_name=None):
        """ShowNodeConnectivityRequest

        The model defined in huaweicloud sdk

        :param task_id: 
        :type task_id: str
        :param queue_name: 
        :type queue_name: str
        """
        
        

        self._task_id = None
        self._queue_name = None
        self.discriminator = None

        self.task_id = task_id
        self.queue_name = queue_name

    @property
    def task_id(self):
        """Gets the task_id of this ShowNodeConnectivityRequest.


        :return: The task_id of this ShowNodeConnectivityRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this ShowNodeConnectivityRequest.


        :param task_id: The task_id of this ShowNodeConnectivityRequest.
        :type task_id: str
        """
        self._task_id = task_id

    @property
    def queue_name(self):
        """Gets the queue_name of this ShowNodeConnectivityRequest.


        :return: The queue_name of this ShowNodeConnectivityRequest.
        :rtype: str
        """
        return self._queue_name

    @queue_name.setter
    def queue_name(self, queue_name):
        """Sets the queue_name of this ShowNodeConnectivityRequest.


        :param queue_name: The queue_name of this ShowNodeConnectivityRequest.
        :type queue_name: str
        """
        self._queue_name = queue_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowNodeConnectivityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdli-3.1.1-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/show_node_connectivity_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowNodeConnectivityRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'queue_name': 'str',
        'task_id': 'str'
    }

    attribute_map = {
        'queue_name': 'queue_name',
        'task_id': 'task_id'
    }

    def __init__(self, queue_name=None, task_id=None):
        """ShowNodeConnectivityRequest

        The model defined in huaweicloud sdk

        :param queue_name: 
        :type queue_name: str
        :param task_id: 
        :type task_id: str
        """
        
        

        self._queue_name = None
        self._task_id = None
        self.discriminator = None

        self.queue_name = queue_name
        self.task_id = task_id

    @property
    def queue_name(self):
        """Gets the queue_name of this ShowNodeConnectivityRequest.


        :return: The queue_name of this ShowNodeConnectivityRequest.
        :rtype: str
        """
        return self._queue_name

    @queue_name.setter
    def queue_name(self, queue_name):
        """Sets the queue_name of this ShowNodeConnectivityRequest.


        :param queue_name: The queue_name of this ShowNodeConnectivityRequest.
        :type queue_name: str
        """
        self._queue_name = queue_name

    @property
    def task_id(self):
        """Gets the task_id of this ShowNodeConnectivityRequest.


        :return: The task_id of this ShowNodeConnectivityRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this ShowNodeConnectivityRequest.


        :param task_id: The task_id of this ShowNodeConnectivityRequest.
        :type task_id: str
        """
        self._task_id = task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowNodeConnectivityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
